# 完善主题动画和UI一致性计划

**目标：** 提升Open WebUI在不同主题下的用户体验，特别是通过增强动画效果和确保UI元素在视觉上保持一致。

**当前状态：**
*   已有一个包含项目中常用CSS选择器的列表 (`css_selectors.md`)。
*   已有一个主题样式文件 (`static/themes/gem.css`)，定义了颜色变量和部分元素的样式。
*   部分UI元素可能缺乏动画或在不同主题下存在样式不一致的问题。

**计划步骤：**

1.  **识别关键UI元素并分析其样式：**
    *   **聊天消息 (`.message.user`, `.message.assistant`)**: 分析其在不同主题下的背景、文字颜色、边距等样式，确定如何添加平滑的进出场动画（例如淡入、从侧边滑入）。
    *   **侧边导航栏 (`#nav`)**: 分析其背景、宽度、以及展开/折叠状态的样式，规划过渡动画。
    *   **按钮和交互元素 (`button`, `.code-expand-btn`, etc.)**: 检查其在`:hover`, `:active`, `:disabled` 状态下的样式和过渡效果，确保在所有主题下都有清晰且一致的视觉反馈。
    *   **代码块 (`.cm-editor`)**: 分析其样式和代码高亮，考虑添加展开/折叠动画，并确保在深色和浅色主题下代码的可读性。
    *   **提示框 (`.tippy-box`)**: 检查其背景、文字颜色和边框样式，确保与当前主题协调，并考虑添加淡入动画。
    *   **加载微光效果 (`.shimmer`)**: 验证其在不同主题背景下的可见性和动画流畅性。
    *   **流程图连接线 (`.svelte-flow__edge`)**: 检查其颜色和样式在不同主题下的显示效果。

2.  **设计和实现动画效果：**
    *   使用CSS `transition` 属性为元素的常见状态变化（如`:hover`, `:active`, 展开/折叠）添加平滑过渡。
    *   对于更复杂的动画（如消息进出场），使用 `@keyframes` 定义动画序列，并通过CSS类或JavaScript动态应用。
    *   确保动画效果不会过于突兀或影响性能。

3.  **优化跨主题的UI一致性：**
    *   审查不同主题CSS文件（`static/themes/*.css`），找出样式定义不一致的地方。
    *   优先使用CSS变量来定义颜色、间距等，以便于在不同主题中统一管理和调整样式。
    *   对于特定主题的样式覆盖，确保使用合适的选择器优先级和 `@media (prefers-color-scheme: dark)` 等媒体查询。

4.  **测试和迭代：**
    *   在不同的主题和浏览器环境下测试动画效果和UI一致性。
    *   根据测试结果进行调整和优化。

**Mermaid 图示例（按钮悬停动画）：**

```mermaid
graph TD
    A[按钮默认状态] --> B{鼠标悬停};
    B --> C[按钮悬停状态];
    C --> D{鼠标移开};
    D --> A;
    C -- 过渡动画 --> A;
    A -- 过渡动画 --> C;